module Mks
  module Rent
    class ClientsController < ApplicationController
      before_action :set_client, only: %i[show update destroy]

      def index
        render json: Mks::Common::MethodResponse.success_response(Client.all)
      end

      def show
        render json: Mks::Common::MethodResponse.success_response(@client)
      end

      def filter
        search = "%#{params[:search].downcase}%"
        equipments = Client.where('lower(name) LIKE ?', search)
        render json: ApplicationRecord.as_json(equipments)
      end

      def create
        client = Client.new(client_params)
        if client.save
          render json: Mks::Common::MethodResponse.success_response(@client, 'Client created successfully!'),
                 status: :created, location: client
        else
          response = Mks::Common::MethodResponse.failure_response(client)
          render json: response, status: :unprocessable_entity
        end
      end

      def update
        if @client.update(client_params)
          render json: Mks::Common::MethodResponse.success_response(@client, 'Client updated successfully!')
        else
          render json: Mks::Common::MethodResponse.failure_response(@client), status: :unprocessable_entity
        end
      end


      private

      def set_client
        @client = Client.find(params[:id])
      end

      def client_params
        params.require(:client).permit(:name, :address)
      end
    end
  end
end