module Mks
  module Rent
    class OfferRequestsController < ApplicationController
      before_action :set_offer_request, only: %i[show destroy]
      before_action :set_service, only: %i[create]

      def index
        data = OfferRequest.where(prepared_by: current_user)
        render json: Mks::Common::MethodResponse.success_response(data)
      end

      def show
        data = ActiveModelSerializers::SerializableResource.new(@offer_request,
                                                                serializer: CompleteOfferRequestSerializer).as_json
        # Remove this when MethodResponse.success_response() is
        # updated to accept a serializer
        response = Mks::Common::MethodResponse.new(true, nil, data, nil, nil)
        render json: response
      end

      def create
        offer_request, success = @service.create(offer_request_params, current_user)
        if success
          render json: Mks::Common::MethodResponse.success_response(offer_request, 'Request created successfully!'),
                 status: :created, location: offer_request
        else
          render json: Mks::Common::MethodResponse.failure_response(offer_request), status: :unprocessable_entity
        end
      end


      private

      def set_service
        @service = OfferRequestService.new
      end

      def adjust_defaults(offer_request)
        offer_request.prepared_by = current_user
        offer_request.status ||= 'DRAFT'
      end

      def set_offer_request
        @offer_request = OfferRequest.find(params[:id])
      end

      def offer_request_params
        params.require(:offer_request).permit(:description,
                                              :destination,
                                              client: %i[id name],
                                              items: %i[equipment_id from to quantity])
      end
    end
  end
end