module Mks
  module Rent
    class OfferRequestService
      def create(params, prepared_by)
        p = params.clone
        id = get_or_create_client(p[:client])
        p.delete(:client)
        items_hash = p.delete(:items)
        offer_request = OfferRequest.new(p)

        unless items_hash
          offer_request.errors.add(:base, 'Request has no items')
          return [offer_request, false]
        end

        offer_request.client_id = id
        offer_request.prepared_by = prepared_by
        offer_request.status = 'DRAFT'

        OfferRequest.transaction do
          offer_request.save!
          items = prepare_items(offer_request.id, items_hash)
          items.each(&:save!)
          return [offer_request, true]
        end
      end

      def update(request, params)
        p = params.clone
        if p[:client]
          id = get_or_create_client(p[:client])
          p.delete(:client)
          request.client_id = id
        end
        updated = request.update(p)
        [request, updated]
      end

      def get_or_create_client(client)
        return client[:id] if client && client[:id]
        Client.create(client).id
      end

      def prepare_items(id, params)
        obj = []
        params.each do |param|
          param[:offer_request_id] = id
          obj << RequestItem.new(param)
        end
        obj
      end
    end
  end
end